aboutsummaryrefslogtreecommitdiff
path: root/lib/imap.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/imap.h')
-rw-r--r--lib/imap.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/imap.h b/lib/imap.h
index e6b9b8944..5e0e228f5 100644
--- a/lib/imap.h
+++ b/lib/imap.h
@@ -49,9 +49,9 @@ typedef enum {
IMAP_LAST /* never used */
} imapstate;
/* This IMAP struct is used in the SessionHandle. All IMAP data that is
connection-oriented must be in imap_conn to properly deal with the fact that
- perhaps the SessionHandle is changed between the times the connection is
+ perhaps the Curl_easy is changed between the times the connection is
used. */
struct IMAP {
curl_pp_transfer transfer;
@@ -49,9 +49,9 @@ typedef enum {
IMAP_LAST /* never used */
} imapstate;
-/* This IMAP struct is used in the SessionHandle. All IMAP data that is
+/* This IMAP struct is used in the Curl_easy. All IMAP data that is
connection-oriented must be in imap_conn to properly deal with the fact that